``pants.stream``
****************

.. automodule:: pants.stream


``Stream``
==========

.. autoclass:: Stream
    :members: connect, close, write, write_file, write_packed, flush, on_read, on_write, on_connect, on_connect_error, on_close

